==> ejc-middlemeasurement-impl-3.0.0-20220525.141048-104-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractaccountEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.business.middlemeasurement.vo.SubcontractaccountdetailVO;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包月度报量台账
 * 
 * @author generator
 * 
 */
@TableName("ejc_middlemeasurement_subcontractaccount")
public class SubcontractaccountEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "bill_state")
	private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	@TableField(value = "project_id")
	private java.lang.Long projectId; // 项目id
	@TableField(value = "project_name")
	private java.lang.String projectName; // 项目名称
	@TableField(value = "org_id")
	private java.lang.Long orgId; // 所属组织id
	@TableField(value = "org_name")
	private java.lang.String orgName; // 所属组织名称
	@TableField(value = "project_department_id")
	private java.lang.Long projectDepartmentId; // 项目部id
	@TableField(value = "bill_code")
	private java.lang.String billCode; // 编码
	@TableField(value = "remarks")
	private java.lang.String remarks; // 备注
	@TableField(value = "statistical_month")
	private java.util.Date statisticalMonth; // 统计月份
	@TableField(value = "application_no")
	private java.lang.String applicationNo; // 报量申请单编号
	@TableField(value = "name")
	private java.lang.String name; // 分包单位名称
	@TableField(value = "reporting_time")
	private java.util.Date reportingTime; // 上报时间
	@TableField(value = "reported_quantities")
	private java.math.BigDecimal reportedQuantities; // 本月上报工程量(除税)
	@TableField(value = "tax_reported_quantities")
	private java.math.BigDecimal taxReportedQuantities; // 本月上报工程量(含税)
	@TableField(value = "cumulative_reporting")
	private java.math.BigDecimal cumulativeReporting; // 至本月累计上报工程量(除税)
	@TableField(value = "tax_cumulative_reporting")
	private java.math.BigDecimal taxCumulativeReporting; // 至本月累计上报工程量(含税)
	@TableField(value = "approval_quantity")
	private java.math.BigDecimal approvalQuantity; // 本月审批工程量(除税)
	@TableField(value = "tax_approval_quantity")
	private java.math.BigDecimal taxApprovalQuantity; // 本月审批工程量(含税)
	@TableField(value = "cumulative_approval")
	private java.math.BigDecimal cumulativeApproval; // 至本月审批工程量(除税)
	@TableField(value = "tax_cumulative_approval")
	private java.math.BigDecimal taxCumulativeApproval; // 至本月审批工程量(含税)
	@TableField(value = "payment_proportion")
	private java.math.BigDecimal paymentProportion; // 合同付款比例(%)
	@TableField(value = "cumulative_payable")
	private java.math.BigDecimal cumulativePayable; // 至本月累计应付款金额(除税)
	@TableField(value = "actual_payment")
	private java.math.BigDecimal actualPayment; // 本月实际付款金额
	@TableField(value = "cumulative_payment")
	private java.math.BigDecimal cumulativePayment; // 至本月累计付款金额
	@TableField(exist = false)
	@SubEntity(serviceName = "subcontractaccountdetailService", pidName = "mid")
	private List<SubcontractaccountdetailEntity> subcontractaccountdetailEntities = new ArrayList<>();

	public void setSubcontractaccountdetailEntities(List<SubcontractaccountdetailEntity> list) {
		this.subcontractaccountdetailEntities = list;
	}

	public List<SubcontractaccountdetailEntity> getSubcontractaccountdetailEntities() {
		return subcontractaccountdetailEntities;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public java.lang.Integer getBillState() {
		return billState;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public void setBillState(java.lang.Integer billState) {
		this.billState = billState;
	}

	/**
	 * 项目id
	 */
	public java.lang.Long getProjectId() {
		return projectId;
	}

	/**
	 * 项目id
	 */
	public void setProjectId(java.lang.Long projectId) {
		this.projectId = projectId;
	}

	/**
	 * 项目名称
	 */
	public java.lang.String getProjectName() {
		return projectName;
	}

	/**
	 * 项目名称
	 */
	public void setProjectName(java.lang.String projectName) {
		this.projectName = projectName;
	}

	/**
	 * 所属组织id
	 */
	public java.lang.Long getOrgId() {
		return orgId;
	}

	/**
	 * 所属组织id
	 */
	public void setOrgId(java.lang.Long orgId) {
		this.orgId = orgId;
	}

	/**
	 * 所属组织名称
	 */
	public java.lang.String getOrgName() {
		return orgName;
	}

	/**
	 * 所属组织名称
	 */
	public void setOrgName(java.lang.String orgName) {
		this.orgName = orgName;
	}

	/**
	 * 项目部id
	 */
	public java.lang.Long getProjectDepartmentId() {
		return projectDepartmentId;
	}

	/**
	 * 项目部id
	 */
	public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
		this.projectDepartmentId = projectDepartmentId;
	}

	/**
	 * 编码
	 */
	public java.lang.String getBillCode() {
		return billCode;
	}

	/**
	 * 编码
	 */
	public void setBillCode(java.lang.String billCode) {
		this.billCode = billCode;
	}

	/**
	 * 备注
	 */
	public java.lang.String getRemarks() {
		return remarks;
	}

	/**
	 * 备注
	 */
	public void setRemarks(java.lang.String remarks) {
		this.remarks = remarks;
	}

	/**
	 * 统计月份
	 */
	public java.util.Date getStatisticalMonth() {
		return statisticalMonth;
	}

	/**
	 * 统计月份
	 */
	public void setStatisticalMonth(java.util.Date statisticalMonth) {
		this.statisticalMonth = statisticalMonth;
	}

	/**
	 * 报量申请单编号
	 */
	public java.lang.String getApplicationNo() {
		return applicationNo;
	}

	/**
	 * 报量申请单编号
	 */
	public void setApplicationNo(java.lang.String applicationNo) {
		this.applicationNo = applicationNo;
	}

	/**
	 * 分包单位名称
	 */
	public java.lang.String getName() {
		return name;
	}

	/**
	 * 分包单位名称
	 */
	public void setName(java.lang.String name) {
		this.name = name;
	}

	/**
	 * 上报时间
	 */
	public java.util.Date getReportingTime() {
		return reportingTime;
	}

	/**
	 * 上报时间
	 */
	public void setReportingTime(java.util.Date reportingTime) {
		this.reportingTime = reportingTime;
	}

	/**
	 * 本月上报工程量(除税)
	 */
	public java.math.BigDecimal getReportedQuantities() {
		return reportedQuantities;
	}

	/**
	 * 本月上报工程量(除税)
	 */
	public void setReportedQuantities(java.math.BigDecimal reportedQuantities) {
		this.reportedQuantities = reportedQuantities;
	}

	/**
	 * 本月上报工程量(含税)
	 */
	public java.math.BigDecimal getTaxReportedQuantities() {
		return taxReportedQuantities;
	}

	/**
	 * 本月上报工程量(含税)
	 */
	public void setTaxReportedQuantities(java.math.BigDecimal taxReportedQuantities) {
		this.taxReportedQuantities = taxReportedQuantities;
	}

	/**
	 * 至本月累计上报工程量(除税)
	 */
	public java.math.BigDecimal getCumulativeReporting() {
		return cumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(除税)
	 */
	public void setCumulativeReporting(java.math.BigDecimal cumulativeReporting) {
		this.cumulativeReporting = cumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(含税)
	 */
	public java.math.BigDecimal getTaxCumulativeReporting() {
		return taxCumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(含税)
	 */
	public void setTaxCumulativeReporting(java.math.BigDecimal taxCumulativeReporting) {
		this.taxCumulativeReporting = taxCumulativeReporting;
	}

	/**
	 * 本月审批工程量(除税)
	 */
	public java.math.BigDecimal getApprovalQuantity() {
		return approvalQuantity;
	}

	/**
	 * 本月审批工程量(除税)
	 */
	public void setApprovalQuantity(java.math.BigDecimal approvalQuantity) {
		this.approvalQuantity = approvalQuantity;
	}

	/**
	 * 本月审批工程量(含税)
	 */
	public java.math.BigDecimal getTaxApprovalQuantity() {
		return taxApprovalQuantity;
	}

	/**
	 * 本月审批工程量(含税)
	 */
	public void setTaxApprovalQuantity(java.math.BigDecimal taxApprovalQuantity) {
		this.taxApprovalQuantity = taxApprovalQuantity;
	}

	/**
	 * 至本月审批工程量(除税)
	 */
	public java.math.BigDecimal getCumulativeApproval() {
		return cumulativeApproval;
	}

	/**
	 * 至本月审批工程量(除税)
	 */
	public void setCumulativeApproval(java.math.BigDecimal cumulativeApproval) {
		this.cumulativeApproval = cumulativeApproval;
	}

	/**
	 * 至本月审批工程量(含税)
	 */
	public java.math.BigDecimal getTaxCumulativeApproval() {
		return taxCumulativeApproval;
	}

	/**
	 * 至本月审批工程量(含税)
	 */
	public void setTaxCumulativeApproval(java.math.BigDecimal taxCumulativeApproval) {
		this.taxCumulativeApproval = taxCumulativeApproval;
	}

	/**
	 * 合同付款比例(%)
	 */
	public java.math.BigDecimal getPaymentProportion() {
		return paymentProportion;
	}

	/**
	 * 合同付款比例(%)
	 */
	public void setPaymentProportion(java.math.BigDecimal paymentProportion) {
		this.paymentProportion = paymentProportion;
	}

	/**
	 * 至本月累计应付款金额(除税)
	 */
	public java.math.BigDecimal getCumulativePayable() {
		return cumulativePayable;
	}

	/**
	 * 至本月累计应付款金额(除税)
	 */
	public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
		this.cumulativePayable = cumulativePayable;
	}

	/**
	 * 本月实际付款金额
	 */
	public java.math.BigDecimal getActualPayment() {
		return actualPayment;
	}

	/**
	 * 本月实际付款金额
	 */
	public void setActualPayment(java.math.BigDecimal actualPayment) {
		this.actualPayment = actualPayment;
	}

	/**
	 * 至本月累计付款金额
	 */
	public java.math.BigDecimal getCumulativePayment() {
		return cumulativePayment;
	}

	/**
	 * 至本月累计付款金额
	 */
	public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
		this.cumulativePayment = cumulativePayment;
	}

}

==> ejc-middlemeasurement-impl-3.0.0-20221118.082653-234-sources.jar: com/ejianc/business/middlemeasurement/bean/SubcontractaccountEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * 分包月度报量台账
 * 
 * @author generator
 * 
 */
@TableName("ejc_middlemeasurement_subcontractaccount")
public class SubcontractaccountEntity extends BaseEntity {
	private static final long serialVersionUID = 1L;

	@TableField(value = "bill_state")
	private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	@TableField(value = "project_id")
	private java.lang.Long projectId; // 项目id
	@TableField(value = "project_name")
	private java.lang.String projectName; // 项目名称
	@TableField(value = "org_id")
	private java.lang.Long orgId; // 所属组织id
	@TableField(value = "org_name")
	private java.lang.String orgName; // 所属组织名称
	@TableField(value = "project_department_id")
	private java.lang.Long projectDepartmentId; // 项目部id
	@TableField(value = "bill_code")
	private java.lang.String billCode; // 编码
	@TableField(value = "remarks")
	private java.lang.String remarks; // 备注
	@TableField(value = "statistical_month")
	private java.util.Date statisticalMonth; // 统计月份
	@TableField(value = "application_no")
	private java.lang.String applicationNo; // 报量申请单编号
	@TableField(value = "name")
	private java.lang.String name; // 分包单位名称
	@TableField(value = "reporting_time")
	private java.util.Date reportingTime; // 上报时间
	@TableField(value = "reported_quantities")
	private java.math.BigDecimal reportedQuantities; // 本月上报工程量(除税)
	@TableField(value = "tax_reported_quantities")
	private java.math.BigDecimal taxReportedQuantities; // 本月上报工程量(含税)
	@TableField(value = "cumulative_reporting")
	private java.math.BigDecimal cumulativeReporting; // 至本月累计上报工程量(除税)
	@TableField(value = "tax_cumulative_reporting")
	private java.math.BigDecimal taxCumulativeReporting; // 至本月累计上报工程量(含税)
	@TableField(value = "approval_quantity")
	private java.math.BigDecimal approvalQuantity; // 本月审批工程量(除税)
	@TableField(value = "tax_approval_quantity")
	private java.math.BigDecimal taxApprovalQuantity; // 本月审批工程量(含税)
	@TableField(value = "cumulative_approval")
	private java.math.BigDecimal cumulativeApproval; // 至本月审批工程量(除税)
	@TableField(value = "tax_cumulative_approval")
	private java.math.BigDecimal taxCumulativeApproval; // 至本月审批工程量(含税)
	@TableField(value = "payment_proportion")
	private java.math.BigDecimal paymentProportion; // 合同付款比例(%)
	@TableField(value = "cumulative_payable")
	private java.math.BigDecimal cumulativePayable; // 至本月累计应付款金额(除税)
	@TableField(value = "actual_payment")
	private java.math.BigDecimal actualPayment; // 本月实际付款金额
	@TableField(value = "cumulative_payment")
	private java.math.BigDecimal cumulativePayment; // 至本月累计付款金额
	@TableField(value="tax_rate")
	private java.math.BigDecimal taxRate; // 税率

	@TableField(exist = false)
	@SubEntity(serviceName = "subcontractaccountdetailService", pidName = "mid")
	private List<SubcontractaccountdetailEntity> subcontractaccountdetailEntities = new ArrayList<>();

	public void setSubcontractaccountdetailEntities(List<SubcontractaccountdetailEntity> list) {
		this.subcontractaccountdetailEntities = list;
	}

	public List<SubcontractaccountdetailEntity> getSubcontractaccountdetailEntities() {
		return subcontractaccountdetailEntities;
	}

	/**
	 * 税率
	 * @return
	 */
	public BigDecimal getTaxRate() {
		return taxRate;
	}

	/**
	 * 税率
	 * @param taxRate
	 */
	public void setTaxRate(BigDecimal taxRate) {
		this.taxRate = taxRate;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public java.lang.Integer getBillState() {
		return billState;
	}

	/**
	 * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
	 */
	public void setBillState(java.lang.Integer billState) {
		this.billState = billState;
	}

	/**
	 * 项目id
	 */
	public java.lang.Long getProjectId() {
		return projectId;
	}

	/**
	 * 项目id
	 */
	public void setProjectId(java.lang.Long projectId) {
		this.projectId = projectId;
	}

	/**
	 * 项目名称
	 */
	public java.lang.String getProjectName() {
		return projectName;
	}

	/**
	 * 项目名称
	 */
	public void setProjectName(java.lang.String projectName) {
		this.projectName = projectName;
	}

	/**
	 * 所属组织id
	 */
	public java.lang.Long getOrgId() {
		return orgId;
	}

	/**
	 * 所属组织id
	 */
	public void setOrgId(java.lang.Long orgId) {
		this.orgId = orgId;
	}

	/**
	 * 所属组织名称
	 */
	public java.lang.String getOrgName() {
		return orgName;
	}

	/**
	 * 所属组织名称
	 */
	public void setOrgName(java.lang.String orgName) {
		this.orgName = orgName;
	}

	/**
	 * 项目部id
	 */
	public java.lang.Long getProjectDepartmentId() {
		return projectDepartmentId;
	}

	/**
	 * 项目部id
	 */
	public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
		this.projectDepartmentId = projectDepartmentId;
	}

	/**
	 * 编码
	 */
	public java.lang.String getBillCode() {
		return billCode;
	}

	/**
	 * 编码
	 */
	public void setBillCode(java.lang.String billCode) {
		this.billCode = billCode;
	}

	/**
	 * 备注
	 */
	public java.lang.String getRemarks() {
		return remarks;
	}

	/**
	 * 备注
	 */
	public void setRemarks(java.lang.String remarks) {
		this.remarks = remarks;
	}

	/**
	 * 统计月份
	 */
	public java.util.Date getStatisticalMonth() {
		return statisticalMonth;
	}

	/**
	 * 统计月份
	 */
	public void setStatisticalMonth(java.util.Date statisticalMonth) {
		this.statisticalMonth = statisticalMonth;
	}

	/**
	 * 报量申请单编号
	 */
	public java.lang.String getApplicationNo() {
		return applicationNo;
	}

	/**
	 * 报量申请单编号
	 */
	public void setApplicationNo(java.lang.String applicationNo) {
		this.applicationNo = applicationNo;
	}

	/**
	 * 分包单位名称
	 */
	public java.lang.String getName() {
		return name;
	}

	/**
	 * 分包单位名称
	 */
	public void setName(java.lang.String name) {
		this.name = name;
	}

	/**
	 * 上报时间
	 */
	public java.util.Date getReportingTime() {
		return reportingTime;
	}

	/**
	 * 上报时间
	 */
	public void setReportingTime(java.util.Date reportingTime) {
		this.reportingTime = reportingTime;
	}

	/**
	 * 本月上报工程量(除税)
	 */
	public java.math.BigDecimal getReportedQuantities() {
		return reportedQuantities;
	}

	/**
	 * 本月上报工程量(除税)
	 */
	public void setReportedQuantities(java.math.BigDecimal reportedQuantities) {
		this.reportedQuantities = reportedQuantities;
	}

	/**
	 * 本月上报工程量(含税)
	 */
	public java.math.BigDecimal getTaxReportedQuantities() {
		return taxReportedQuantities;
	}

	/**
	 * 本月上报工程量(含税)
	 */
	public void setTaxReportedQuantities(java.math.BigDecimal taxReportedQuantities) {
		this.taxReportedQuantities = taxReportedQuantities;
	}

	/**
	 * 至本月累计上报工程量(除税)
	 */
	public java.math.BigDecimal getCumulativeReporting() {
		return cumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(除税)
	 */
	public void setCumulativeReporting(java.math.BigDecimal cumulativeReporting) {
		this.cumulativeReporting = cumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(含税)
	 */
	public java.math.BigDecimal getTaxCumulativeReporting() {
		return taxCumulativeReporting;
	}

	/**
	 * 至本月累计上报工程量(含税)
	 */
	public void setTaxCumulativeReporting(java.math.BigDecimal taxCumulativeReporting) {
		this.taxCumulativeReporting = taxCumulativeReporting;
	}

	/**
	 * 本月审批工程量(除税)
	 */
	public java.math.BigDecimal getApprovalQuantity() {
		return approvalQuantity;
	}

	/**
	 * 本月审批工程量(除税)
	 */
	public void setApprovalQuantity(java.math.BigDecimal approvalQuantity) {
		this.approvalQuantity = approvalQuantity;
	}

	/**
	 * 本月审批工程量(含税)
	 */
	public java.math.BigDecimal getTaxApprovalQuantity() {
		return taxApprovalQuantity;
	}

	/**
	 * 本月审批工程量(含税)
	 */
	public void setTaxApprovalQuantity(java.math.BigDecimal taxApprovalQuantity) {
		this.taxApprovalQuantity = taxApprovalQuantity;
	}

	/**
	 * 至本月审批工程量(除税)
	 */
	public java.math.BigDecimal getCumulativeApproval() {
		return cumulativeApproval;
	}

	/**
	 * 至本月审批工程量(除税)
	 */
	public void setCumulativeApproval(java.math.BigDecimal cumulativeApproval) {
		this.cumulativeApproval = cumulativeApproval;
	}

	/**
	 * 至本月审批工程量(含税)
	 */
	public java.math.BigDecimal getTaxCumulativeApproval() {
		return taxCumulativeApproval;
	}

	/**
	 * 至本月审批工程量(含税)
	 */
	public void setTaxCumulativeApproval(java.math.BigDecimal taxCumulativeApproval) {
		this.taxCumulativeApproval = taxCumulativeApproval;
	}

	/**
	 * 合同付款比例(%)
	 */
	public java.math.BigDecimal getPaymentProportion() {
		return paymentProportion;
	}

	/**
	 * 合同付款比例(%)
	 */
	public void setPaymentProportion(java.math.BigDecimal paymentProportion) {
		this.paymentProportion = paymentProportion;
	}

	/**
	 * 至本月累计应付款金额(除税)
	 */
	public java.math.BigDecimal getCumulativePayable() {
		return cumulativePayable;
	}

	/**
	 * 至本月累计应付款金额(除税)
	 */
	public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
		this.cumulativePayable = cumulativePayable;
	}

	/**
	 * 本月实际付款金额
	 */
	public java.math.BigDecimal getActualPayment() {
		return actualPayment;
	}

	/**
	 * 本月实际付款金额
	 */
	public void setActualPayment(java.math.BigDecimal actualPayment) {
		this.actualPayment = actualPayment;
	}

	/**
	 * 至本月累计付款金额
	 */
	public java.math.BigDecimal getCumulativePayment() {
		return cumulativePayment;
	}

	/**
	 * 至本月累计付款金额
	 */
	public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
		this.cumulativePayment = cumulativePayment;
	}

}
